@@ -41,6 +41,7 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesDoneResponse,
     ListEntitiesFanResponse,
     ListEntitiesLightResponse,
+    ListEntitiesLockResponse,
     ListEntitiesNumberResponse,
     ListEntitiesRequest,
     ListEntitiesSelectResponse,
@@ -49,6 +50,8 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesSirenResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
+    LockCommandRequest,
+    LockStateResponse,
     NumberCommandRequest,
     NumberStateResponse,
     SelectCommandRequest,
@@ -95,6 +98,9 @@ from .model import (
     LegacyCoverCommand,
     LightInfo,
     LightState,
+    LockCommand,
+    LockEntityState,
+    LockInfo,
     LogLevel,
     NumberInfo,
     NumberState,
@@ -131,7 +137,23 @@ class APIClient:
         keepalive: float = 15.0,
         zeroconf_instance: ZeroconfInstanceType = None,
         noise_psk: Optional[str] = None,
+        expected_name: Optional[str] = None,
     ):
+        """Create a client, this object is shared across sessions.
+
+        :param address: The address to connect to; for example an IP address
+          or .local name for mDNS lookup.
+        :param port: The port to connect to
+        :param password: Optional password to send to the device for authentication
+        :param client_info: User Agent string to send.
+        :param keepalive: The keepalive time in seconds (ping interval) for detecting stale connections.
+            Every keepalive seconds a ping is sent, if no pong is received the connection is closed.
+        :param zeroconf_instance: Pass a zeroconf instance to use if an mDNS lookup is necessary.
+        :param noise_psk: Encryption preshared key for noise transport encrypted sessions.
+        :param expected_name: Require the devices name to match the given expected name.
+            Can be used to prevent accidentally connecting to a different device if
+            IP passed as address but DHCP reassigned IP.
+        """
         self._params = ConnectionParams(
             address=address,
             port=port,
@@ -141,10 +163,19 @@ class APIClient:
             zeroconf_instance=zeroconf_instance,
             # treat empty psk string as missing (like password)
             noise_psk=noise_psk or None,
+            expected_name=expected_name,
         )
         self._connection: Optional[APIConnection] = None
         self._cached_name: Optional[str] = None
 
+    @property
+    def expected_name(self) -> Optional[str]:
+        return self._params.expected_name
+
+    @expected_name.setter
+    def expected_name(self, value: Optional[str]) -> None:
+        self._params.expected_name = value
+
     @property
     def address(self) -> str:
         return self._params.address
@@ -233,6 +264,7 @@ class APIClient:
             ListEntitiesServicesResponse: None,
             ListEntitiesCameraResponse: CameraInfo,
             ListEntitiesClimateResponse: ClimateInfo,
+            ListEntitiesLockResponse: LockInfo,
         }
 
         def do_append(msg: message.Message) -> bool:
@@ -276,6 +308,7 @@ class APIClient:
             SwitchStateResponse: SwitchState,
             TextSensorStateResponse: TextSensorState,
             ClimateStateResponse: ClimateState,
+            LockStateResponse: LockEntityState,
         }
 
         image_stream: Dict[int, bytes] = {}
@@ -606,6 +639,22 @@ class APIClient:
         assert self._connection is not None
         await self._connection.send_message(req)
 
+    async def lock_command(
+        self,
+        key: int,
+        command: LockCommand,
+        code: Optional[str] = None,
+    ) -> None:
+        self._check_authenticated()
+
+        req = LockCommandRequest()
+        req.key = key
+        req.command = command
+        if code is not None:
+            req.code = code
+        assert self._connection is not None
+        await self._connection.send_message(req)
+
     async def execute_service(
         self, service: UserService, data: ExecuteServiceDataType
     ) -> None:
