@@ -32,6 +32,7 @@ from .api_pb2 import (  # type: ignore
 from .core import (
     MESSAGE_TYPE_TO_PROTO,
     APIConnectionError,
+    BadNameAPIError,
     InvalidAuthAPIError,
     PingFailedAPIError,
     ProtocolAPIError,
@@ -55,6 +56,7 @@ class ConnectionParams:
     keepalive: float
     zeroconf_instance: hr.ZeroconfInstanceType
     noise_psk: Optional[str]
+    expected_name: Optional[str]
 
 
 class ConnectionState(enum.Enum):
@@ -162,7 +164,7 @@ class APIConnection:
         except asyncio.TimeoutError as err:
             raise SocketAPIError(f"Timeout while connecting to {sockaddr}") from err
 
-        _LOGGER.debug("%s: Opened socket for", self._params.address)
+        _LOGGER.debug("%s: Opened socket", self._params.address)
 
     async def _connect_init_frame_helper(self) -> None:
         """Step 3 in connect process: initialize the frame helper and init read loop."""
@@ -174,7 +176,7 @@ class APIConnection:
             fh = self._frame_helper = APINoiseFrameHelper(
                 reader, writer, self._params.noise_psk
             )
-            await fh.perform_handshake()
+            await fh.perform_handshake(self._params.expected_name)
 
         self._connection_state = ConnectionState.SOCKET_OPENED
 
@@ -206,6 +208,15 @@ class APIConnection:
             )
             raise APIConnectionError("Incompatible API version.")
 
+        if (
+            self._params.expected_name is not None
+            and resp.name != ""
+            and resp.name != self._params.expected_name
+        ):
+            raise BadNameAPIError(
+                f"Server sent a different name '{resp.name}'", resp.name
+            )
+
         self._connection_state = ConnectionState.CONNECTED
 
     async def _connect_start_ping(self) -> None:
@@ -226,7 +237,7 @@ class APIConnection:
 
                 # Re-check connection state
                 if not self._is_socket_open:
-                    return
+                    return  # type: ignore[unreachable]
 
                 try:
                     await self._ping()
@@ -255,7 +266,7 @@ class APIConnection:
                 "Connection can only be used once, connection is not in init state"
             )
 
-        try:
+        async def _do_connect() -> None:
             addr = await self._connect_resolve_host()
             await self._connect_socket_connect(addr)
             await self._connect_init_frame_helper()
@@ -263,6 +274,12 @@ class APIConnection:
             await self._connect_start_ping()
             if login:
                 await self.login()
+
+        try:
+            # Allow 2 minutes for connect; this is only as a last measure
+            # to protect from issues if some part of the connect process mistakenly
+            # does not have a timeout
+            await asyncio.wait_for(_do_connect(), timeout=120.0)
         except Exception:  # pylint: disable=broad-except
             # Always clean up the connection if an error occured during connect
             self._connection_state = ConnectionState.CLOSED
@@ -336,7 +353,7 @@ class APIConnection:
                     data=encoded,
                 )
             )
-        except Exception as err:  # pylint: disable=broad-except
+        except SocketAPIError as err:  # pylint: disable=broad-except
             # If writing packet fails, we don't know what state the frames
             # are in anymore and we have to close the connection
             await self._report_fatal_error(err)
